%define major                   23
%define libname                 %mklibname prelude %{major}
%define cppmajor                8
%define libcpp                  %mklibname preludecpp %{cppmajor}
%define libnamedevel            %mklibname prelude -d

Name:           libprelude
Version:        3.1.0
Release:        %mkrel 2
Summary:        Prelude Hybrid Intrusion Detection System Library
License:        GPLv2+
Group:          System/Libraries
URL:            https://www.prelude-siem.org/
Source0:        https://www.prelude-siem.org/attachments/download/721/%{name}-%{version}.tar.gz
Patch0:         libprelude-3.1.0-linking.patch
BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  flex
BuildRequires:  gtk-doc
BuildRequires:  multiarch-utils
BuildRequires:  swig
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libltdl-devel
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(lua) >= 5.2
BuildRequires:  pkgconfig(python2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(ruby)
BuildRequires:  pkgconfig(zlib)

%description
The Prelude Library is a collection of generic functions providing
communication between the Prelude Hybrid IDS suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the commandline, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libname}
Summary:        Prelude Hybrid Intrusion Detection System Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
The Prelude Library is a collection of generic functions providing
communication between the Prelude Hybrid IDS suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the commandline, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libcpp}
Summary:        Prelude Hybrid Intrusion Detection System Library
Group:          System/Libraries

%description -n %{libcpp}
The Prelude Library is a collection of generic functions providing
communication between the Prelude Hybrid IDS suite components. It
provides a convenient interface for sending alerts to Prelude
Manager with transparent SSL, failover and replication support,
asynchronous events and timer interfaces, an abstracted
configuration API (hooking at the commandline, the configuration
line, or wide configuration, available from the Manager), and a
generic plugin API. It allows you to easily turn your favorite
security program into a Prelude sensor.

%package -n %{libnamedevel}
Summary:        Libraries, includes, etc. for developing Prelude IDS sensors
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libcpp} = %{version}-%{release}
Requires:       libltdl-devel
Provides:       %{name}-devel = %{version}-%{release}
Provides:       prelude-devel = %{version}-%{release}

%description -n %{libnamedevel}
Libraries, include files, etc you can use to develop Prelude IDS
sensors using the Prelude Library. The Prelude Library is a
collection of generic functions providing communication between
the Prelude Hybrid IDS suite componentst It provides a convenient
interface for sending alerts to Prelude Manager with transparent
SSL, failover and replication support, asynchronous events and
timer interfaces, an abstracted configuration API (hooking at the
commandline, the configuration line, or wide configuration,
available from the Manager), and a generic plugin API. It allows
you to easily turn your favorite security program into a Prelude
sensor.

%package -n prelude-tools
Summary:        The interface for %{libname}
Group:          Networking/Other
Requires:       %{libname} = %{version}-%{release}

%description -n prelude-tools
Provides a convenient interface for sending alerts to Prelude
Manager.

%package -n python-prelude
Summary:        Python 2 bindings for prelude
Group:          Development/Python
Requires:       %{libname} = %{version}-%{release}

%description -n python-prelude
Provides python 2 bindings for prelude.

%package -n python3-prelude
Summary:        Python 3 bindings for prelude
Group:          Development/Python
Requires:       %{libname} = %{version}-%{release}

%description -n python3-prelude
Provides python 3 bindings for prelude.

%package -n perl-prelude
Summary:        Perl bindings for prelude
Group:          Development/Perl
Requires:       %{libname} = %{version}-%{release}

%description -n perl-prelude
Provides perl bindings for prelude.

%package -n ruby-prelude
Summary:        Ruby bindings for prelude
Group:          Development/Ruby
Requires:       %{libname} = %{version}-%{release}

%description -n ruby-prelude
Provides ruby bindings for prelude.

%package -n lua-prelude
Summary:        Lua bindings for prelude
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Requires:       lua

%description -n lua-prelude
Provides Lua bindings for prelude generated by SWIG.

%prep
%setup -q
%autopatch -p1

%build
%configure2_5x \
    --without-included-ltdl \
    --disable-static \
    --enable-shared \
    --with-swig \
    --with-python2 \
    --with-python3 \
    --with-perl-installdirs=vendor \
    --without-included-regex \
    --includedir=%{_includedir}/%{name} \
    --enable-gtk-doc \
    --with-html-dir=%{_docdir}/%{libnamedevel}
%make_build

%install
%make_install

%{_bindir}/chrpath -d %{buildroot}%{_libdir}/*.so.*

find %{buildroot} -name '*.la' -delete

%multiarch_binaries %{buildroot}%{_bindir}/libprelude-config

%files -n %{libname}
%doc AUTHORS ChangeLog README INSTALL
%{_libdir}/libprelude.so.%{major}
%{_libdir}/libprelude.so.%{major}.*

%files -n %{libcpp}
%{_libdir}/libpreludecpp.so.%{cppmajor}
%{_libdir}/libpreludecpp.so.%{cppmajor}.*

%files -n %{libnamedevel}
%doc %{_docdir}/%{libnamedevel}
%{multiarch_bindir}/%{name}-config
%{_datadir}/%{name}/swig
%{_bindir}/%{name}-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/%{name}/
%{_datadir}/aclocal/*.m4
%{_mandir}/man1/%{name}-config.1*

%files -n prelude-tools
%doc AUTHORS ChangeLog README INSTALL
%{_bindir}/prelude-adduser
%{_bindir}/prelude-admin
%{_mandir}/man1/prelude-admin.1*
%dir %{_sysconfdir}/prelude
%dir %{_sysconfdir}/prelude/default
%dir %{_sysconfdir}/prelude/profile
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/prelude/default/*.conf
%dir %{_var}/spool/prelude

%files -n python-prelude
%{python2_sitearch}/*

%files -n python3-prelude
%{python3_sitearch}/*

%files -n perl-prelude
%{perl_vendorarch}/*.pm
%{perl_vendorarch}/auto/Prelude

%files -n ruby-prelude
%{ruby_sitearchdir}/*

%files -n lua-prelude
%{_libdir}/lua/*/prelude.so


%changelog
* Sun Oct 16 2016 wally <wally> 3.1.0-2.mga6
+ Revision: 1061116
- add patch to fix underlinking

* Sat Oct 15 2016 daviddavid <daviddavid> 3.1.0-1.mga6
+ Revision: 1060909
- new version: 3.1.0 (mga#19451)
- enable lua support
- disable unwanted static libraries
- update BRs list

* Sat Jun 18 2016 pterjan <pterjan> 1.2.6-5.mga6
+ Revision: 1022153
- Rebuild for perl 5.22.2

* Mon Jan 11 2016 luigiwalser <luigiwalser> 1.2.6-4.mga6
+ Revision: 921820
- rebuild for gnutls

  + philippem <philippem>
    - remove twice added with-swig

* Sat Dec 05 2015 philippem <philippem> 1.2.6-3.mga6
+ Revision: 908402
- build with our patched swig, provide ruby bindings files

  + pterjan <pterjan>
    - Force regeneration of swig binding

  + tv <tv>
    - rebuild for python 3.5

  + spuhler <spuhler>
    - rebuild with python-3.5

* Thu Sep 10 2015 fwang <fwang> 1.2.6-1.mga6
+ Revision: 875506
- update file list
- add python3 sub package
- update file list
- update libmajor and enable ruby
- 1.2.6
- rebuild for new libgcrypt

* Sat Jun 27 2015 tv <tv> 1.0.1-18.mga6
+ Revision: 846149
- rebuild with soname-ified perl

* Wed Jun 24 2015 sander85 <sander85> 1.0.1-17.mga6
+ Revision: 841776
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 1.0.1-16.mga5
+ Revision: 744205
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0.1-15.mga5
+ Revision: 726835
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0.1-14.mga5
+ Revision: 681718
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 pterjan <pterjan> 1.0.1-13.mga5
+ Revision: 643921
- Fix build with perl 5.20
- Rebuild for perl 5.20

  + spuhler <spuhler>
    - rebuild against perl-5.20

  + jquelin <jquelin>
    - perl 5.20.0 rebuild

* Sat May 31 2014 pterjan <pterjan> 1.0.1-9.mga5
+ Revision: 628304
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.0.1-8.mga4
+ Revision: 542694
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 1.0.1-7.mga4
+ Revision: 497868
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Sep 21 2013 fwang <fwang> 1.0.1-6.mga4
+ Revision: 482868
- rebuild for ruby 2.0

* Wed May 29 2013 fwang <fwang> 1.0.1-5.mga4
+ Revision: 430415
- rebuild for new perl

* Sat Jan 12 2013 umeabot <umeabot> 1.0.1-4.mga3
+ Revision: 357992
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 fwang <fwang> 1.0.1-3.mga3
+ Revision: 344596
- update file list
- update file list

* Thu Nov 01 2012 fwang <fwang> 1.0.1-2.mga3
+ Revision: 312002
- add patch from pld-linux to build with ruby 1.9
- rebuild for new ruby

* Sun Sep 02 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 287174
- update file list
- add fedora patch to build with glibc
- fix build with latest gcc
- new version 1.0.1

* Fri Jun 01 2012 pterjan <pterjan> 1.0.0-10.mga3
+ Revision: 252600
- Better fix for python binding now that swig is updated

* Fri Jun 01 2012 pterjan <pterjan> 1.0.0-9.mga3
+ Revision: 252588
- BuildRequires swig as I am patching the interface file
- Fix build of python binding
- Fix build with new gnutls

  + fwang <fwang>
    - rebuild for new perl

  + jquelin <jquelin>
    - perl 5.16 rebuild

* Tue Aug 02 2011 fwang <fwang> 1.0.0-6.mga2
+ Revision: 131392
- rebuild for new gnutls

* Sun Jun 12 2011 ahmad <ahmad> 1.0.0-5.mga2
+ Revision: 104504
- Rebuild for perl-5.14.0

* Mon Feb 21 2011 ahmad <ahmad> 1.0.0-4.mga1
+ Revision: 55726
- rebuild to make all pythonegg requires/provides lowercase

* Wed Jan 19 2011 jquelin <jquelin> 1.0.0-3.mga1
+ Revision: 23790
- rebuild

* Mon Jan 17 2011 pterjan <pterjan> 1.0.0-2.mga1
+ Revision: 21359
- Rebuild for python 2.7

* Sat Jan 15 2011 blino <blino> 1.0.0-1.mga1
+ Revision: 19272
- add patch from OpenEmbbeded to fix build with libtool 2.4

  + ahmad <ahmad>
    - drop unneeded scriptlets

  + pterjan <pterjan>
    - imported package libprelude


* Sun Apr 25 2010 Funda Wang <fwang@mandriva.org> 1.0.0-1mdv2010.1
+ Revision: 538616
- new version 1.0.0

* Tue Jan 19 2010 Frederik Himpe <fhimpe@mandriva.org> 0.9.25-1mdv2010.1
+ Revision: 493821
- update to new version 0.9.25

* Mon Nov 23 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.24.1-3mdv2010.1
+ Revision: 469376
- second try...

* Wed Nov 18 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.24.1-2mdv2010.1
+ Revision: 467243
- really link against system libltdl.so.7

* Fri Aug 14 2009 Frederik Himpe <fhimpe@mandriva.org> 0.9.24.1-1mdv2010.0
+ Revision: 416395
- update to new version 0.9.24.1

* Tue Jun 09 2009 Frederik Himpe <fhimpe@mandriva.org> 0.9.23-1mdv2010.0
+ Revision: 384504
- Update to new version 0.9.23

* Wed May 20 2009 Funda Wang <fwang@mandriva.org> 0.9.22-1mdv2010.0
+ Revision: 377921
- New version 0.9.22

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 0.9.21.3-1mdv2009.1
+ Revision: 319833
- fix ltdl path
- BR libltdl-devel
- New version 0.9.21.3

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 0.9.21.2-3mdv2009.1
+ Revision: 319730
- fix str fmt
- rebuild for new python

* Tue Dec 02 2008 Götz Waschk <waschk@mandriva.org> 0.9.21.2-2mdv2009.1
+ Revision: 309159
- rebuild to get rid of libtasn1 dep

* Fri Oct 17 2008 Funda Wang <fwang@mandriva.org> 0.9.21.2-1mdv2009.1
+ Revision: 294711
- New version 0.9.21.2

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 0.9.21.1-1mdv2009.1
+ Revision: 292854
- install to vendor
- perl-bindings are now installed in a different way
- no need to install perl bindings seperatedly
- New version 0.9.20.1

* Sat Sep 06 2008 Funda Wang <fwang@mandriva.org> 0.9.20.1-1mdv2009.0
+ Revision: 281996
- New version 0.9.20.1

* Wed Aug 06 2008 Funda Wang <fwang@mandriva.org> 0.9.19-1mdv2009.0
+ Revision: 264167
- fix file list
- new version 0.9.19

* Fri Jul 25 2008 Funda Wang <fwang@mandriva.org> 0.9.18.1-1mdv2009.0
+ Revision: 249446
- New version 0.9.18.1

* Fri Jul 18 2008 Funda Wang <fwang@mandriva.org> 0.9.18-1mdv2009.0
+ Revision: 238344
- New version 0.9.18

* Fri Jul 18 2008 Funda Wang <fwang@mandriva.org> 0.9.17.2-1mdv2009.0
+ Revision: 238146
- New version 0.9.17.2

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 29 2008 David Walluck <walluck@mandriva.org> 0.9.17-1mdv2009.0
+ Revision: 199117
- 0.9.17

* Fri Jan 25 2008 David Walluck <walluck@mandriva.org> 0.9.16.2-2mdv2008.1
+ Revision: 157831
- rebuild
- 0.9.16.2

* Mon Jan 21 2008 Thierry Vignaud <tv@mandriva.org> 0.9.16.1-3mdv2008.1
+ Revision: 155662
- rebuild for new perl

* Mon Jan 21 2008 Funda Wang <fwang@mandriva.org> 0.9.16.1-2mdv2008.1
+ Revision: 155600
- rebuild against latest gnutls

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 24 2007 David Walluck <walluck@mandriva.org> 0.9.16.1-1mdv2008.1
+ Revision: 111738
- 0.9.16.1

* Thu Oct 11 2007 David Walluck <walluck@mandriva.org> 0.9.16-1mdv2008.1
+ Revision: 97055
- 0.9.16

* Wed Sep 05 2007 David Walluck <walluck@mandriva.org> 0.9.15.2-1mdv2008.0
+ Revision: 80324
- 0.9.15.2

* Thu Aug 23 2007 David Walluck <walluck@mandriva.org> 0.9.15-1mdv2008.0
+ Revision: 70678
- 0.9.15
- remove incorrect Conflicts

  + Funda Wang <fwang@mandriva.org>
    - Drop BR libnetfilter
      Use py_requires macro
    - BR libnetfilter_queue

* Tue Aug 21 2007 Funda Wang <fwang@mandriva.org> 0.9.14-3mdv2008.0
+ Revision: 68212
- Obsoletes old devel name

* Mon Aug 20 2007 David Walluck <walluck@mandriva.org> 0.9.14-2mdv2008.0
+ Revision: 68082
- new lib policy
- add static lib package
- regenerate configure in %%prep
- more strict directory permissions
- change html-dir (still not ideal)

* Wed May 16 2007 David Walluck <walluck@mandriva.org> 0.9.14-1mdv2008.0
+ Revision: 27203
- 0.9.14


* Sat Mar 31 2007 David Walluck <walluck@mandriva.org> 0.9.13.2-1mdv2007.1
+ Revision: 150126
- 0.9.13.2
- 0.9.13.1

* Tue Feb 20 2007 David Walluck <walluck@mandriva.org> 0.9.13-1mdv2007.1
+ Revision: 123167
- add libprelude-0.9.13.txt
- 0.9.13

* Fri Feb 09 2007 David Walluck <walluck@mandriva.org> 0.9.12.2-1mdv2007.1
+ Revision: 118277
- 0.9.12.2

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 0.9.12.1-1mdv2007.1
+ Revision: 105097
- 0.9.12.1

* Thu Dec 21 2006 David Walluck <walluck@mandriva.org> 0.9.12-1mdv2007.1
+ Revision: 100905
- 0.9.12

* Thu Oct 19 2006 David Walluck <walluck@mandriva.org> 0.9.11-3mdv2007.0
+ Revision: 71045
- fix build
- remove onceonly patch (fixed upstream)
- 0.9.11
- Import libprelude

* Fri Jul 14 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.10-1mdv2007.0
- 0.9.10 (Major feature enhancements)
- added P2 (missing m4 macros)

* Wed Jun 07 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.9-1mdv2007.0
- 0.9.9 (Major bugfixes)

* Mon May 15 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8-2mdk
- make it build on 2006

* Mon May 15 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8-1mdk
- 0.9.8
- force INSTALLDIRS=vendor (P1)

* Wed Mar 22 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.7.1-1mdk
- 0.9.7.1 (Major bugfixes)

* Thu Mar 09 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.7-1mdk
- 0.9.7 (Major bugfixes)

* Mon Mar 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.6.1-1mdk
- 0.9.6.1

* Thu Mar 02 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.6-1mdk
- 0.9.6 (Major bugfixes)

* Mon Feb 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.5-1mdk
- 0.9.5 (Minor bugfixes)

* Mon Jan 30 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.4-1mdk
- 0.9.4 (Minor bugfixes)

* Wed Jan 11 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-4mdk
- fix deps

* Tue Jan 10 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-3mdk
- use conflicts instead of obsoletes for the devel sub package (fcrozat)

* Tue Jan 10 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-2mdk
- fix deps

* Tue Jan 10 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-1mdk
- 0.9.3
- fix spool dir location (P0)
- added the python and perl sub packages
- fix deps

* Sat Jan 07 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.2-1mdk
- 0.9.2

* Thu Dec 29 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.1-1mdk
- 0.9.1

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 0.8.10-3mdk
- rebuilt against openssl-0.9.8a

* Tue Jan 25 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.8.10-2mdk
- fix conflicting declaration with MySQL-4.1.x
- fix deps and conditional %%multiarch
- lib64 fixes

* Thu Apr 22 2004 Laurent Culioli <laurent@mandrake.org> 0.8.10-1mdk
- 0.8.10

